@@ -14,21 +14,21 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 try:
-    from PySide6.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PySide6.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox
     from PySide6.QtCore import Qt, QTranslator, QCoreApplication, QLocale
     from PySide6.QtGui import QIcon
 except:
-    from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox
     from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
     from PyQt5.QtGui import QIcon
 
 from persepolis.gui.customized_widgets import MyQDateTimeEdit
 from persepolis.gui import resources
 
+
 class KeyCapturingWindow_Ui(QWidget):
     def __init__(self, persepolis_setting):
         super().__init__()
-        icon = QIcon()
 
         self.persepolis_setting = persepolis_setting
 
@@ -85,7 +85,6 @@ class KeyCapturingWindow_Ui(QWidget):
 class Setting_Ui(QWidget):
     def __init__(self, persepolis_setting):
         super().__init__()
-        icon = QIcon()
 
         self.persepolis_setting = persepolis_setting
 
@@ -199,6 +198,10 @@ class Setting_Ui(QWidget):
         self.dont_check_certificate_checkBox = QCheckBox(self.download_options_tab)
         download_options_tab_verticalLayout.addWidget(self.dont_check_certificate_checkBox)
 
+        # remote time
+        self.remote_time_checkBox = QCheckBox(self.download_options_tab)
+        download_options_tab_verticalLayout.addWidget(self.remote_time_checkBox)
+
         # change aria2 path
         aria2_path_verticalLayout = QVBoxLayout()
 
@@ -242,20 +245,6 @@ class Setting_Ui(QWidget):
 
         save_as_tab_verticalLayout.addLayout(self.download_folder_horizontalLayout)
 
-        # temp_download_folder
-        self.temp_horizontalLayout = QHBoxLayout()
-
-        self.temp_download_label = QLabel(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_label)
-
-        self.temp_download_lineEdit = QLineEdit(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_lineEdit)
-
-        self.temp_download_pushButton = QPushButton(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_pushButton)
-
-        save_as_tab_verticalLayout.addLayout(self.temp_horizontalLayout)
-
         # create subfolder
         self.subfolder_checkBox = QCheckBox(self.save_as_tab)
         save_as_tab_verticalLayout.addWidget(self.subfolder_checkBox)
@@ -411,6 +400,10 @@ class Setting_Ui(QWidget):
         self.keep_awake_checkBox = QCheckBox()
         style_tab_verticalLayout.addWidget(self.keep_awake_checkBox)
 
+        # check clipboard
+        self.check_clipboard_checkBox = QCheckBox()
+        style_tab_verticalLayout.addWidget(self.check_clipboard_checkBox)
+
         style_tab_verticalLayout.addStretch(1)
 
         # columns_tab
@@ -588,7 +581,11 @@ class Setting_Ui(QWidget):
 
         self.dont_check_certificate_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Don't use certificate to verify the peers"))
         self.dont_check_certificate_checkBox.setToolTip(
-                QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option avoids SSL/TLS handshake failure. But use it at your own risk!</p></body></html>"))
+            QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option avoids SSL/TLS handshake failure. But use it at your own risk!</p></body></html>"))
+
+        self.remote_time_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Remote time"))
+        self.remote_time_checkBox.setToolTip(
+            QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Retrieve timestamp of the remote file from the remote HTTP/FTP server and if it is available, apply it to the local file.</p></body></html>"))
 
         self.aria2_path_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Change Aria2 default path'))
         self.aria2_path_pushButton.setText(QCoreApplication.translate("setting_ui_tr", 'Change'))
@@ -599,19 +596,16 @@ class Setting_Ui(QWidget):
         self.aria2_path_pushButton.setToolTip(aria2_path_tooltip)
 
         self.setting_tabWidget.setTabText(self.setting_tabWidget.indexOf(
-            self.download_options_tab),  QCoreApplication.translate("setting_ui_tr", "Download Options"))
+            self.download_options_tab), QCoreApplication.translate("setting_ui_tr", "Download Options"))
 
         self.download_folder_label.setText(QCoreApplication.translate("setting_ui_tr", "Download folder: "))
         self.download_folder_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
 
-        self.temp_download_label.setText(QCoreApplication.translate("setting_ui_tr", "Temporary download folder: "))
-        self.temp_download_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
-
         self.subfolder_checkBox.setText(QCoreApplication.translate(
             "setting_ui_tr", "Create subfolders for Music,Videos, ... in default download folder"))
 
         self.setting_tabWidget.setTabText(
-            self.setting_tabWidget.indexOf(self.save_as_tab),  QCoreApplication.translate("setting_ui_tr", "Save As"))
+            self.setting_tabWidget.indexOf(self.save_as_tab), QCoreApplication.translate("setting_ui_tr", "Save As"))
 
         self.enable_notifications_checkBox.setText(
             QCoreApplication.translate("setting_ui_tr", "Enable Notification Sounds"))
@@ -619,7 +613,7 @@ class Setting_Ui(QWidget):
         self.volume_label.setText(QCoreApplication.translate("setting_ui_tr", "Volume: "))
 
         self.setting_tabWidget.setTabText(self.setting_tabWidget.indexOf(
-            self.notifications_tab),  QCoreApplication.translate("setting_ui_tr", "Notifications"))
+            self.notifications_tab), QCoreApplication.translate("setting_ui_tr", "Notifications"))
 
         self.style_label.setText(QCoreApplication.translate("setting_ui_tr", "Style: "))
         self.color_label.setText(QCoreApplication.translate("setting_ui_tr", "Color scheme: "))
@@ -658,11 +652,16 @@ class Setting_Ui(QWidget):
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option will prevent the system from going to sleep.\
             It is necessary if your power manager is suspending the system automatically. </p></body></html>"))
 
+        self.check_clipboard_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Check system clipboard for copied links"))
+        self.check_clipboard_checkBox.setToolTip(
+            QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>The program will automatically check the clipboard for copied links.\
+            </p></body></html>"))
+
         self.wait_queue_time.setToolTip(
             QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Format HH:MM</p></body></html>"))
 
         self.setting_tabWidget.setTabText(
-            self.setting_tabWidget.indexOf(self.style_tab),  QCoreApplication.translate("setting_ui_tr", "Preferences"))
+            self.setting_tabWidget.indexOf(self.style_tab), QCoreApplication.translate("setting_ui_tr", "Preferences"))
 
 # columns_tab
         self.show_column_label.setText(QCoreApplication.translate("setting_ui_tr", 'Show these columns:'))
@@ -683,7 +682,7 @@ class Setting_Ui(QWidget):
 
 # Video Finder options tab
         self.setting_tabWidget.setTabText(self.setting_tabWidget.indexOf(
-            self.video_finder_tab), QCoreApplication.translate("setting_ui_tr",  "Video Finder Options"))
+            self.video_finder_tab), QCoreApplication.translate("setting_ui_tr", "Video Finder Options"))
 
         self.max_links_label.setText(QCoreApplication.translate("setting_ui_tr", 'Maximum number of links to capture:<br/>'
                                                                 '<small>(If browser sends multiple video links at a time)</small>'))
